/* 
 * File:   main.c
 * Author: Alex Gruener
 *
 * LEDs on Explorer 16 are going to the following pins on the plugin-module:
 * Desc.  Pin on plugin-module    Pin on PIC32MZ2048ECH100
 * D3     17                      RA0
 * D4     38                      RA1
 * D5     58                      RA2
 * D6     59                      RA3
 * D7     60                      RF13
 * D8     61                      RF12
 * D9     91                      RA6
 * D10    92                      RA7
 *
 * PGC and PGD pair on PIC32MZ2048ECH100
 * PGEC   26 (RB6)                PGEC2 (RB6)
 * PGED   27 (RB7)                PGED2 (RB7)
 *
 * Created on 19. Juni 2014, 14:21
 */

#include <stdio.h>
#include <stdlib.h>
#include <xc.h>      // Also automatically includes <cp0defs.h> for CP0 register defines
#include "TYPES.h"

#define LED9_BIT   (1uL << 6)
#define LED10_BIT  (1uL << 7)

static const U8 _acData[500 * 1024] = {0};

int main(int argc, char** argv) {
  int j;
  U32 v;
  //
  //   FSYS => / PBxDIV => PBCLKx
  //   FPB Peripheral Bus Frequency       DC-100 MHz For PBCLKx, 'x' != 7
  //                                      DC-200 MHz For PBCLK7
  // Default dividers: PBCLK1-6, 8: SYSCLK / 2
  // Default dividers: PBCLK7:      SYSCLK / 1
  //
  // _InitPBCLKs();
  //
  // Initialize wait-states
  //
  PRECON = 0
         | (2 << 0) // 2 wait states
         | (3 << 4) // Enable prefetch for instructions + data
         ;
  LATACLR  = LED9_BIT | LED10_BIT;  // Initially, switch LEDs off
  TRISACLR = LED9_BIT | LED10_BIT;  // Configure LEDs as output
  j = 0;
  while (1) {
    //
    // CountReg is incremented every other CPU clock cycle (1/2 CPU clock)
    // Always toggle LEDs 9 & 10
    // LED 9 toggles at 2 Hz
    // LED 10 toggles at 1 Hz
    //
    j = _CP0_GET_COUNT() >> 20; // Divide j by 1 Mio. (Assume 64 MHz CPU clock => 32 MHz CountReg "clock")
    if (j & (1 << 5)) {     // True for every other 250ms
      LATASET = LED9_BIT + (_acData[200]);;
    } else {
      LATACLR = LED9_BIT;
#if SMALL_CHANGE
      LATACLR = LED9_BIT;
      LATACLR = LED9_BIT;
      LATACLR = LED9_BIT;
      LATACLR = LED9_BIT;
      LATACLR = LED9_BIT;
#endif
    }
    if (j & (1 << 6)) {     // True for every other 500ms
      LATASET = LED10_BIT;
    } else {
      LATACLR = LED10_BIT;
    }
  }
  return (EXIT_SUCCESS);
}

